pub struct RequestBody {
pub description: Option<String>,
pub content: Map<MediaType>,
pub required: Option<bool>,
pub extensions: Extensions,
}Expand description
A request body.
Fields
description: Option<String>A description of the body. CommonMark syntax may be used.
content: Map<MediaType>The body’s representations, keyed by media type or media type range.
More than one entry describes a body the server accepts in several encodings.
required: Option<bool>Whether the body is mandatory. Defaults to false.
extensions: ExtensionsSpecification extensions.
Implementations
Sourceimpl RequestBody
impl RequestBody
Sourcepub fn new(media_type: impl Into<String>, content: MediaType) -> Self
pub fn new(media_type: impl Into<String>, content: MediaType) -> Self
Creates a required body with a single media type.
Sourcepub fn with_media_type(
self,
media_type: impl Into<String>,
content: MediaType,
) -> Self
pub fn with_media_type( self, media_type: impl Into<String>, content: MediaType, ) -> Self
Adds another representation of the same body.
Sourcepub fn with_description(self, description: impl Into<String>) -> Self
pub fn with_description(self, description: impl Into<String>) -> Self
Sets the description.