Module header

Module header 

The Header Object, and the headers the specification refuses to describe.

Structs

Header
A response header, or a header used by an Encoding.

Enums

HeaderShape
How a header’s value is described.

Constants

IGNORED_HEADERS
Header names that must not be declared in a headers map.
IGNORED_HEADER_PARAMETERS
Header names that must not be declared as ParameterIn::Header parameters.

Functions

is_ignored_header
Whether name is a header that must not be declared in a headers map.
is_ignored_header_parameter
Whether name is a header that must not be declared as a parameter.