Module status

Module status 

The keys of a Responses Object: exact status codes and the five wildcards.

Structs

InvalidStatusPattern
The error returned when a string is not a legal Responses key.

Enums

StatusPattern
The key of an entry in a Responses map.