pub struct ServerVariable {
pub enumeration: Option<Vec<String>>,
pub default_value: String,
pub description: Option<String>,
pub extensions: Extensions,
}Expand description
A substitution variable for a templated Server::url.
Fields
enumeration: Option<Vec<String>>The set of values this variable may take.
When present it must not be empty, and must contain
default_value.
default_value: StringThe value to use for substitution when none is supplied.
Unlike JSON Schema’s default, this field is required.
description: Option<String>A description of this variable. CommonMark syntax may be used.
extensions: ExtensionsSpecification extensions.
Implementations