Module violation

Module violation 

What a validator reports: how bad it is, where it is, and what is wrong.

Structs

Violation
A single problem found in a document.

Enums

Severity
How seriously to take a Violation.
SpecError
A way in which a document fails to conform.